.. collective.solr documentation master file, created by
   sphinx-quickstart on Thu Oct 24 08:27:50 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
Solr integration for the Plone CMS
==================================

.. include:: introduction.rst

.. include:: status.rst

Contents
========

This documentation will describe all necessary information to setup and use `Solr`_ in combination with `Plone`_.

.. toctree::
    :maxdepth: 4

    base/index
    usage/index
    development/index

.. toctree::
    :maxdepth: 1

    CHANGES


.. include:: credits.rst

.. include:: contributors.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: indexes.rst
